@@ -1,9 +1,5 @@
-# -*- coding: utf-8 -*-
-from __future__ import unicode_literals
-
 from collections import OrderedDict
 from functools import wraps
-from six import iteritems
 
 from flask import request, current_app, has_app_context
 
@@ -178,7 +174,7 @@ def _marshal(data, fields, envelope=None, skip_none=False, mask=None, ordered=Fa
         (k, marshal(data, v, skip_none=skip_none, ordered=ordered))
         if isinstance(v, dict)
         else __format_field(k, v)
-        for k, v in iteritems(fields)
+        for k, v in fields.items()
     )
 
     if skip_none:
