@@ -1,12 +1,8 @@
-# -*- coding: utf-8 -*-
-from __future__ import unicode_literals
-
 import inspect
 import warnings
 import logging
 from collections import namedtuple, OrderedDict
 
-import six
 from flask import request
 from flask.views import http_method_funcs
 
@@ -132,7 +128,7 @@ class Namespace(object):
 
     def doc(self, shortcut=None, **kwargs):
         """A decorator to add some api documentation to the decorated object"""
-        if isinstance(shortcut, six.text_type):
+        if isinstance(shortcut, str):
             kwargs["id"] = shortcut
         show = shortcut if isinstance(shortcut, bool) else True
 
@@ -357,8 +353,8 @@ class Namespace(object):
 
 def unshortcut_params_description(data):
     if "params" in data:
-        for name, description in six.iteritems(data["params"]):
-            if isinstance(description, six.string_types):
+        for name, description in data["params"].items():
+            if isinstance(description, str):
                 data["params"][name] = {"description": description}
 
 
